# typescript_analyzer - Module Enrichment

**File:** `./src/autodoc/typescript_analyzer.py`
**Last Updated:** 2025-06-27T16:13:59.053027
**Total Entities:** 43
**Functions:** 0
**Classes:** 2

## Module Entities

*No enrichments available yet. Run `autodoc enrich` to add detailed descriptions.*

### Classes

#### `TypeScriptAnalyzer` (line 50)
> Analyzes TypeScript files using tree-sitter to extract code entities.

#### `TypeScriptEntity` (line 27)
> Extended CodeEntity for TypeScript-specific properties.
